@@ -10,13 +10,20 @@ __all__ = ['register']
 
 def register():
     Pool.register(
+        stock.Configuration,
+        stock.ConfigurationMeasurement,
         stock.Move,
         stock.ShipmentIn,
         stock.ShipmentInReturn,
         stock.ShipmentOut,
         stock.ShipmentOutReturn,
-        stock.Package,
         module='stock_shipment_measurements', type_='model')
+    Pool.register(
+        stock.Package,
+        stock.ShipmentOutPackage,
+        stock.ShipmentInReturnPackage,
+        module='stock_shipment_measurements', type_='model',
+        depends=['stock_package'])
     Pool.register(
         module='stock_shipment_measurements', type_='wizard')
     Pool.register(
